/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://java.net/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.othermarshallers;

import javax.annotation.Nonnull;
import java.util.HashSet;
import java.util.Set;
import it.tidalwave.util.As;
import it.tidalwave.util.Id;
import it.tidalwave.util.Key;
import it.tidalwave.util.NotFoundException;
import it.tidalwave.mobile.media.Media;
import it.tidalwave.semantic.io.spi.AsStatementMarshaller;
import it.tidalwave.semantic.io.spi.StatementMarshaller.Context;
import static it.tidalwave.semantic.vocabulary.FoafVocabulary.*;
import static it.tidalwave.semantic.vocabulary.RdfVocabulary.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class MediaMarshaller extends AsStatementMarshaller
  {
    @Override @Nonnull
    public void marshal (final @Nonnull As entity, final @Nonnull Context context)
      {
        try
          {
            super.marshal(entity, context);
            final Media media = (Media)entity;
            final Set<Key<?>> keys = new HashSet<Key<?>>(media.getKeys());
            keys.remove(Media.ID);

            context.addStatement(media, ID_RDF_TYPE, ID_FOAF_DOCUMENT);

            for (final Key<?> key : keys)
              {
                if (!key.equals(Media.MIME_TYPE) && !key.equals(Media.DURATION))
                  {
                    context.addStatement(media, new Id(key.stringValue()), media.get(key));
                  }
              }
          }
        catch (NotFoundException e)
          {
            throw new RuntimeException(e);
          }
      }
  }
